==> vivotek_4.6.0.51.tar.gz: www/js/utils_loaddirect.js <==
var vivotekrestart = false;
var liveVelocidad = false;
var lp;
if (!String.prototype.startsWith)
{
	String.prototype.startsWith = function(searchString, position)
	{
		position = position || 0;
		return this.substr(position, searchString.length) === searchString;
	};
}

function make_header(section)
{
	var hasEvidences = true;
	$.ajax(
	{
		url: pathcgi + "cgi-bin/vparcgi.cgi?computerid=" + computerid + "&oper=checkmodule&module1=evidence&module2=view&module3=logo&module4=p1&module5=p2&d=" + getStringNormalDate(new Date()) + localStorage.getItem("TOKEN"),
		async: false,
		success: function(data)
		{
			CheckTokenValidity(data);
			if (data[0].evidence.startsWith("FAIL"))
			{
				hasEvidences = false;
			}
			if (data[0].view.startsWith("LIST"))
			{
				liveVelocidad = true;
			}
			$(".sitetitle").css("background", "url(images/" + data[0].logo + ") no-repeat top center");
		}
	});
	if (DEFINE_INTERFACE == "ZKTECO")
	{
		if (window.location !== window.parent.location)
		{
			// The page is in an iFrames 
		}
		else
		{
			// The page is not in an iFrame 
			//window.location.href = window.location.origin;
		}
		$("#tooplate_header").hide();
		//TODO: Pendiente idiomas evExpress.localization.formatMessage("<TAG>")
		var header = "<div class='top_01'>" +
			"<div class='top_mt1'><img src='images/tooplate_logo_zkteco.png'></div>" +
			"<div class='top_mt2 bold f14'><label></label>&nbsp;&nbsp;<label style='display: none;''></label></div>" +
			"</div> " +
			"<div class='top_02'><div class='nav'>" +
			"<div class='nav_1' ><a>" + DevExpress.localization.formatMessage("Live") + "</a></div>" +
			"<div class='nav_1' ><a>" + DevExpress.localization.formatMessage("Playback") + "</a></div>" +
			"<div class='nav_1' ><a>" + DevExpress.localization.formatMessage("File") + "</a></div>" +
			"<div class='nav_1' ><a>" + DevExpress.localization.formatMessage("Setup") + "</a></div>" +
			"<div class='nav_1' ><a>" + DevExpress.localization.formatMessage("Log") + "</a></div>" +
			"<div class='nav_1' ><a>" + DevExpress.localization.formatMessage("Alarm") + "</a><div style='height: 100%; vertical-align: middle; display: inline-block;'><img src='images/32a.gif'></div></div>" +
			"<div class='nav_1' ><a>" + DevExpress.localization.formatMessage("Face") + "Face</a></div>" +
			"<div class='nav_2' id='liindex'><a id='aindex'  href='index.html'>" + DevExpress.localization.formatMessage("LPR") + "</a></div>" +
			"</div></div>";
		//"<br style='clear: left' />";
		var sideMenu = "<div class='main_right2 fl' style='height: 100%; '><div class='main_right_mid2 r_bg'>" +
			"<div id='side_menu_index' class='main_right_1'><a id='aindex' href='index.html' style='cursor: pointer;'>" + DevExpress.localization.formatMessage("Main") + "</a></div>" +
			//"<div id='side_menu_review' class='main_right_1'><a d='areview' href='review.html' style='cursor: pointer;'>Review</a></div>"+
			"<div id='side_menu_list' class='main_right_1'><a id='alist' href='lists.html' style='cursor: pointer;'>" + DevExpress.localization.formatMessage("Lists") + "</a></div>" +
			"<div id='side_menu_camconfiguration' class='main_right_1'><a id='acamconfiguration' href='camconfiguration.html' style='cursor: pointer;'>" + DevExpress.localization.formatMessage("Setup") + "</a></div>" +
			(hasEvidences ? ("<div id='side_menu_evidence' class='main_right_1'><a id='aevidence' href='evidence.html' style='cursor: pointer;'>" + DevExpress.localization.formatMessage("Evidence") + "</a></div>") : "") +
			"<div id='side_menu_configuration' class='main_right_1'><a id='aconfiguration' href='configuration.html' style='cursor: pointer;'>" + DevExpress.localization.formatMessage("Advanced Setup") + "</a></div>" +
			"<div id='side_menu_historic' class='main_right_1'><a id='ahistoric' href='historic.html' style='cursor: pointer;'>" + DevExpress.localization.formatMessage("Audit") + "</a></div>" +
			"<div id='side_menu_logs' class='main_right_1'><a id='alogs' href='logs.html' style='cursor: pointer;'>Debug</a></div>" +
			"</div></div>";
		//Elimianr header 
		//$( "#tooplate_header" ).empty();
		$("#tooplate_header").remove("#title");
		$("#tooplate_header").remove("#tooplate_menu");
		//Añadimos nuevo mení incluido imagen
		$("#tooplate_header").prepend(header);
		//Añadimos menú lateral
		$("#tooplate_container").prepend(sideMenu);
		//Seleccion de item
		$("#side_menu_" + section).addClass("main_right_1_current");
	}
	else
	{
		var header = "<ul>" +
			"<li id='liindex' ><a id='aindex'  href='index.html'  >" + DevExpress.localization.formatMessage("Live") + "</a></li>" +
			"<li id='lireview' ><a id='areview' href='review.html' >" + DevExpress.localization.formatMessage("Review") + "</a></li>" +
			"<li id='lilist' ><a id='alist' href='lists.html'  >" + DevExpress.localization.formatMessage("Lists") + "</a></li>" +
			"<li id='licamconfiguration'  ><a id='acamconfiguration' href='camconfiguration.html' >" + DevExpress.localization.formatMessage("LPR configuration") + "</a></li>" +
			(hasEvidences ? ("<li id='lievidence'  ><a id='aevidence' href='evidence.html' >" + DevExpress.localization.formatMessage("Evidence") + "</a></li>") : "") +
			"<li id='liconfiguration' ><a id='aconfiguration' href='configuration.html' >" + DevExpress.localization.formatMessage("General configuration") + "</a></li>" +
			"<li id='lihistoric'><a id='ahistoric' href='historic.html'>" + DevExpress.localization.formatMessage("Audit") + "</a></li>" +
			"<li id='lilogs'><a id='alogs' href='logs.html' >" + DevExpress.localization.formatMessage("Logs") + "</a></li>" +
			"</ul>" +
			"<br style='clear: left' />";
		$("#tooplate_menu").append(header);
		$("#li" + section).addClass("last");
		$("#a" + section).addClass("selected");
	}
}

function getStringNormalDate(date_input)
{
	var day = date_input.getDate();
	var days = day;
	if (day < 10)
	{
		days = "0" + day;
	}
	var month = date_input.getMonth() + 1;
	var months = month;
	if (month < 10)
	{
		months = "0" + month;
	}
	var year = date_input.getFullYear();
	var hour = date_input.getHours();
	var hours = hour;
	if (hour < 10)
	{
		hours = "0" + hour;
	}
	var minute = date_input.getMinutes();
	var minutes = minute;
	if (minute < 10)
	{
		minutes = "0" + minute;
	}
	var second = date_input.getSeconds();
	var seconds = second;
	if (second < 10)
	{
		seconds = "0" + second;
	}
	var miliseconds = date_input.getMilliseconds();
	if (miliseconds < 10)
	{
		miliseconds = "00" + miliseconds;
	}
	else if (miliseconds < 100)
	{
		miliseconds = "0" + miliseconds;
	}
	return year + "-" + months + "-" + days + "T" + hours + ":" + minutes + ":" + seconds + "." + miliseconds;
}

function getStringNormalDate2(date_input)
{
	var day = date_input.getDate();
	var days = day;
	if (day < 10)
	{
		days = "0" + day;
	}
	var month = date_input.getMonth() + 1;
	var months = month;
	if (month < 10)
	{
		months = "0" + month;
	}
	var year = date_input.getFullYear();
	var hour = date_input.getHours();
	var hours = hour;
	if (hour < 10)
	{
		hours = "0" + hour;
	}
	var minute = date_input.getMinutes();
	var minutes = minute;
	if (minute < 10)
	{
		minutes = "0" + minute;
	}
	var second = date_input.getSeconds();
	var seconds = second;
	if (second < 10)
	{
		seconds = "0" + second;
	}
	return year + "-" + months + "-" + days + "T" + hours + ":" + minutes + ":" + seconds + ".999";
}

function checkstatus()
{
	$.ajax(
		{
			dataType: "json",
			url: pathcgi + "cgi-bin/vparcgi.cgi?computerid=" + computerid + "&oper=getident&d=" + getStringNormalDate(new Date()) + localStorage.getItem("TOKEN"),
			async: false,
			success: function(data)
			{
				CheckTokenValidity(data);
				ident = data;
				$.ajax(
					{
						url: pathcgi + "/cgi-bin/vparcgi.cgi?computerid=1&oper=status&d=" + getStringNormalDate(new Date()) + localStorage.getItem("TOKEN"),
						async: false,
						success: function(data)
						{
							CheckTokenValidity(data);
							if (data[11].value == -1)
							{
								$.ajax(
								{
									url: pathcgi + "/cgi-bin/vparcgi.cgi?computerid=1&oper=checkservice&d=" + getStringNormalDate(new Date()) + localStorage.getItem("TOKEN"),
									async: false
								});
							}
						},
						error: function()
						{
							$.ajax(
								{
									url: pathcgi + "/cgi-bin/vparcgi.cgi?computerid=1&oper=checkservice&d=" + getStringNormalDate(new Date()) + localStorage.getItem("TOKEN"),
									async: false,
									success: function(data)
									{
										CheckTokenValidity(data);
									});
							}
						});
				}
			});
	}

	function startapp()
	{
		$.ajax(
		{
			url: pathcgi + "../cgi-bin/admin/vadpctrl.cgi?cmd=start&idx=" + ident + "&d=" + getStringNormalDate(new Date()) + localStorage.getItem("TOKEN"),
			success: function(data)
			{
				CheckTokenValidity(data);
				if (lp === undefined)
				{
					// se ejecutan estas instrucciones
				}
				else
				{
					lp.hide();
					DevExpress.ui.notify("Application restarted", "success", 600);
				}
			}
		});
	}

	function restartapp()
	{
		if (vivotekrestart)
		{
			$.ajax(
			{
				url: pathcgi + "../cgi-bin/admin/vadpctrl.cgi?cmd=stop&idx=" + ident + "&d=" + getStringNormalDate(new Date()) + localStorage.getItem("TOKEN"),
				success: function(data)
				{
					CheckTokenValidity(data);
				}
			});
			setTimeout(startapp, 1000);
		}
		else
		{
			$.ajax(
			{
				url: pathcgi + "cgi-bin/vparcgi.cgi?computerid=1&oper=restartservice&d=" + getStringNormalDate(new Date()) + localStorage.getItem("TOKEN"),
				success: function(data)
				{
					CheckTokenValidity(data);
				}
			});
			lp.hide();
			DevExpress.ui.notify("Application restarted", "success", 600);
		}
	}

	function CreateToolTip(id, evidences, imagepath, resultleft, resulttop, resultright, resultbottom, width, height)
	{
		$("#tooltip" + id).dxTooltip(
		{
			target: "#icimg" + id,
			showEvent: "mouseenter",
			hideEvent: "mouseleave",
			position: "left",
			contentTemplate: function(data)
			{
				var widthdraw = 700;
				var heightdraw = 394;
				var hdr = 0;
				var wdr = 700;
				if (evidences == 0)
				{
					hdr = 395;
					wdr = 700;
				}
				if (evidences == 1)
				{
					hdr = (heightdraw * 0.75) * 2;
					wdr = wdr * 0.75;
					widthdraw = widthdraw * 0.75;
					heightdraw = heightdraw * 0.75;
				}
				if (evidences == 2)
				{
					hdr = (heightdraw * 0.6) * 3;
					wdr = wdr * 0.6;
					widthdraw = widthdraw * 0.60;
					heightdraw = heightdraw * 0.60;
				}
				data.html("<canvas id='cvas" + id + "' width='" + wdr + "' height='" + hdr + "' ></canvas>");
				var canvas = document.getElementById('cvas' + id);
				var ctx = canvas.getContext('2d');
				var tmpImg = new Image();
				tmpImg.src = pathcgi + "cgi-bin/vparcgi.cgi?computerid=" + computerid + "&oper=getimage&path=" + imagepath + localStorage.getItem("TOKEN");
				tmpImg.onload = function()
				{
					ctx.drawImage(tmpImg, 0, 0, widthdraw, heightdraw);
					ctx.rect(resultleft * (widthdraw / width), resulttop * (heightdraw / height), (resultright - resultleft) * (widthdraw / width), (resultbottom - resulttop) * (heightdraw / height));
					ctx.strokeStyle = 'green';
					ctx.lineWidth = 3;
					ctx.stroke();
				}
				if (evidences > 0)
				{
					var tmpImg2 = new Image();
					tmpImg2.src = pathcgi + "cgi-bin/vparcgi.cgi?computerid=" + computerid + "&oper=getimage&path=" + imagepath.substring(0, imagepath.length - 4) + "_ev1.jpg" + localStorage.getItem("TOKEN");
					tmpImg2.onload = function()
					{
						ctx.drawImage(tmpImg2, 0, heightdraw + 3, widthdraw, heightdraw);
						ctx.stroke();
					}
				}
				if (evidences > 1)
				{
					var tmpImg3 = new Image();
					tmpImg3.src = pathcgi + "cgi-bin/vparcgi.cgi?computerid=" + computerid + "&oper=getimage&path=" + imagepath.substring(0, imagepath.length - 4) + "_ev2.jpg" + localStorage.getItem("TOKEN");
					tmpImg3.onload = function()
					{
						ctx.drawImage(tmpImg3, 0, (heightdraw * 2) + 6, widthdraw, heightdraw);
						ctx.stroke();
					}
				}
			}
		});
	}

	function CreateToolTipTop(id, evidences, imagepath, resultleft, resulttop, resultright, resultbottom, width, height)
	{
		$("#tooltip" + id).dxTooltip(
		{
			target: "#icimg" + id,
			showEvent: "mouseenter",
			hideEvent: "mouseleave",
			position: "top",
			contentTemplate: function(data)
			{
				var widthdraw = 700;
				var heightdraw = 394;
				var hdr = 395;
				var wdr = 700;
				if (evidences == 0)
				{
					hdr = 395;
					wdr = 700;
				}
				if (evidences == 1)
				{
					hdr = heightdraw * 0.75;
					wdr = (wdr * 0.75) * 2;
					widthdraw = widthdraw * 0.75;
					heightdraw = heightdraw * 0.75;
				}
				if (evidences == 2)
				{
					hdr = heightdraw * 0.6;
					wdr = (wdr * 0.6) * 3;
					widthdraw = widthdraw * 0.60;
					heightdraw = heightdraw * 0.60;
				}
				data.html("<canvas id='cvas" + id + "' width='" + wdr + "' height='" + hdr + "' ></canvas>");
				var canvas = document.getElementById('cvas' + id);
				var ctx = canvas.getContext('2d');
				var tmpImg = new Image();
				tmpImg.src = pathcgi + "cgi-bin/vparcgi.cgi?computerid=" + computerid + "&oper=getimage&path=" + imagepath + localStorage.getItem("TOKEN");
				tmpImg.onload = function()
				{
					ctx.drawImage(tmpImg, 0, 0, widthdraw, heightdraw);
					ctx.rect(resultleft * (widthdraw / width), resulttop * (heightdraw / height), (resultright - resultleft) * (widthdraw / width), (resultbottom - resulttop) * (heightdraw / height));
					ctx.strokeStyle = 'green';
					ctx.lineWidth = 3;
					ctx.stroke();
				}
				if (evidences > 0)
				{
					var tmpImg2 = new Image();
					tmpImg2.src = pathcgi + "cgi-bin/vparcgi.cgi?computerid=" + computerid + "&oper=getimage&path=" + imagepath.substring(0, imagepath.length - 4) + "_ev1.jpg" + localStorage.getItem("TOKEN");
					tmpImg2.onload = function()
					{
						ctx.drawImage(tmpImg2, widthdraw + 3, 0, widthdraw, heightdraw);
						ctx.stroke();
					}
				}
				if (evidences > 1)
				{
					var tmpImg3 = new Image();
					tmpImg3.src = pathcgi + "cgi-bin/vparcgi.cgi?computerid=" + computerid + "&oper=getimage&path=" + imagepath.substring(0, imagepath.length - 4) + "_ev2.jpg" + localStorage.getItem("TOKEN");
					tmpImg3.onload = function()
					{
						ctx.drawImage(tmpImg3, (widthdraw * 2) + 6, 0, widthdraw, heightdraw);
						ctx.stroke();
					}
				}
			}
		});
	}

==> vivotek_4.8.1.20.tar.gz: www/js/utils_loaddirect.js <==
var vivotekrestart = false;
var liveVelocidad = false;
var lp;
if (!String.prototype.startsWith)
{
	String.prototype.startsWith = function(searchString, position)
	{
		position = position || 0;
		return this.substr(position, searchString.length) === searchString;
	};
}

function make_header(section)
{
	var hasEvidences = true;
	$.ajax(
	{
		url: pathcgi + "cgi-bin/vparcgi.cgi?computerid=" + computerid + "&oper=checkmodule&module1=evidence&module2=view&module3=logo&module4=p1&module5=p2&d=" + getStringNormalDate(new Date()) + localStorage.getItem("TOKEN"),
		async: false,
		success: function(data)
		{
			CheckTokenValidity(data);
			if (data[0].evidence == "FAIL")
			{
				hasEvidences = false;
			}
			if (data[0].view == "LIST")
			{
				liveVelocidad = true;
			}
			$(".sitetitle").css("background", "url(images/" + data[0].logo + ") no-repeat top center");
		}
	});
	if (DEFINE_INTERFACE == "ZKTECO")
	{
		if (window.location !== window.parent.location)
		{
			// The page is in an iFrames 
		}
		else
		{
			// The page is not in an iFrame 
			//window.location.href = window.location.origin;
		}
		$("#tooplate_header").hide();
		//TODO: Pendiente idiomas evExpress.localization.formatMessage("<TAG>")
		var header = "<div class='top_01'>" +
			"<div class='top_mt1'><img src='images/tooplate_logo_zkteco.png'></div>" +
			"<div class='top_mt2 bold f14'><label></label>&nbsp;&nbsp;<label style='display: none;''></label></div>" +
			"</div> " +
			"<div class='top_02'><div class='nav'>" +
			"<div class='nav_1' ><a>" + DevExpress.localization.formatMessage("Live") + "</a></div>" +
			"<div class='nav_1' ><a>" + DevExpress.localization.formatMessage("Playback") + "</a></div>" +
			"<div class='nav_1' ><a>" + DevExpress.localization.formatMessage("File") + "</a></div>" +
			"<div class='nav_1' ><a>" + DevExpress.localization.formatMessage("Setup") + "</a></div>" +
			"<div class='nav_1' ><a>" + DevExpress.localization.formatMessage("Log") + "</a></div>" +
			"<div class='nav_1' ><a>" + DevExpress.localization.formatMessage("Alarm") + "</a><div style='height: 100%; vertical-align: middle; display: inline-block;'><img src='images/32a.gif'></div></div>" +
			"<div class='nav_1' ><a>" + DevExpress.localization.formatMessage("Face") + "Face</a></div>" +
			"<div class='nav_2' id='liindex'><a id='aindex'  href='index.html'>" + DevExpress.localization.formatMessage("LPR") + "</a></div>" +
			"</div></div>";
		//"<br style='clear: left' />";
		var sideMenu = "<div class='main_right2 fl' style='height: 100%; '><div class='main_right_mid2 r_bg'>" +
			"<div id='side_menu_index' class='main_right_1'><a id='aindex' href='index.html' style='cursor: pointer;'>" + DevExpress.localization.formatMessage("Main") + "</a></div>" +
			//"<div id='side_menu_review' class='main_right_1'><a d='areview' href='review.html' style='cursor: pointer;'>Review</a></div>"+
			"<div id='side_menu_list' class='main_right_1'><a id='alist' href='lists.html' style='cursor: pointer;'>" + DevExpress.localization.formatMessage("Lists") + "</a></div>" +
			"<div id='side_menu_camconfiguration' class='main_right_1'><a id='acamconfiguration' href='camconfiguration.html' style='cursor: pointer;'>" + DevExpress.localization.formatMessage("Setup") + "</a></div>" +
			(hasEvidences ? ("<div id='side_menu_evidence' class='main_right_1'><a id='aevidence' href='evidence.html' style='cursor: pointer;'>" + DevExpress.localization.formatMessage("Evidence") + "</a></div>") : "") +
			"<div id='side_menu_configuration' class='main_right_1'><a id='aconfiguration' href='configuration.html' style='cursor: pointer;'>" + DevExpress.localization.formatMessage("Advanced Setup") + "</a></div>" +
			"<div id='side_menu_historic' class='main_right_1'><a id='ahistoric' href='historic.html' style='cursor: pointer;'>" + DevExpress.localization.formatMessage("Audit") + "</a></div>" +
			"<div id='side_menu_logs' class='main_right_1'><a id='alogs' href='logs.html' style='cursor: pointer;'>Debug</a></div>" +
			"</div></div>";
		//Elimianr header 
		//$( "#tooplate_header" ).empty();
		$("#tooplate_header").remove("#title");
		$("#tooplate_header").remove("#tooplate_menu");
		//Añadimos nuevo mení incluido imagen
		$("#tooplate_header").prepend(header);
		//Añadimos menú lateral
		$("#tooplate_container").prepend(sideMenu);
		//Seleccion de item
		$("#side_menu_" + section).addClass("main_right_1_current");
	}
	else
	{
		var header = "<ul>" +
			"<li id='liindex' ><a id='aindex'  href='index.html'  >" + DevExpress.localization.formatMessage("Live") + "</a></li>" +
			"<li id='lireview' ><a id='areview' href='review.html' >" + DevExpress.localization.formatMessage("Review") + "</a></li>" +
			"<li id='lilist' ><a id='alist' href='lists.html'  >" + DevExpress.localization.formatMessage("Lists") + "</a></li>" +
			"<li id='licamconfiguration'  ><a id='acamconfiguration' href='camconfiguration.html' >" + DevExpress.localization.formatMessage("LPR configuration") + "</a></li>" +
			(hasEvidences ? ("<li id='lievidence'  ><a id='aevidence' href='evidence.html' >" + DevExpress.localization.formatMessage("Evidence") + "</a></li>") : "") +
			"<li id='liconfiguration' ><a id='aconfiguration' href='configuration.html' >" + DevExpress.localization.formatMessage("General configuration") + "</a></li>" +
			"<li id='lihistoric'><a id='ahistoric' href='historic.html'>" + DevExpress.localization.formatMessage("Audit") + "</a></li>" +
			"<li id='lilogs'><a id='alogs' href='logs.html' >" + DevExpress.localization.formatMessage("Logs") + "</a></li>" +
			"</ul>" +
			"<br style='clear: left' />";
		$("#tooplate_menu").append(header);
		$("#li" + section).addClass("last");
		$("#a" + section).addClass("selected");
	}
}

function getStringNormalDate(date_input)
{
	var day = date_input.getDate();
	var days = day;
	if (day < 10)
	{
		days = "0" + day;
	}
	var month = date_input.getMonth() + 1;
	var months = month;
	if (month < 10)
	{
		months = "0" + month;
	}
	var year = date_input.getFullYear();
	var hour = date_input.getHours();
	var hours = hour;
	if (hour < 10)
	{
		hours = "0" + hour;
	}
	var minute = date_input.getMinutes();
	var minutes = minute;
	if (minute < 10)
	{
		minutes = "0" + minute;
	}
	var second = date_input.getSeconds();
	var seconds = second;
	if (second < 10)
	{
		seconds = "0" + second;
	}
	var miliseconds = date_input.getMilliseconds();
	if (miliseconds < 10)
	{
		miliseconds = "00" + miliseconds;
	}
	else if (miliseconds < 100)
	{
		miliseconds = "0" + miliseconds;
	}
	return year + "-" + months + "-" + days + "T" + hours + ":" + minutes + ":" + seconds + "." + miliseconds;
}

function getStringNormalDate2(date_input)
{
	var day = date_input.getDate();
	var days = day;
	if (day < 10)
	{
		days = "0" + day;
	}
	var month = date_input.getMonth() + 1;
	var months = month;
	if (month < 10)
	{
		months = "0" + month;
	}
	var year = date_input.getFullYear();
	var hour = date_input.getHours();
	var hours = hour;
	if (hour < 10)
	{
		hours = "0" + hour;
	}
	var minute = date_input.getMinutes();
	var minutes = minute;
	if (minute < 10)
	{
		minutes = "0" + minute;
	}
	var second = date_input.getSeconds();
	var seconds = second;
	if (second < 10)
	{
		seconds = "0" + second;
	}
	return year + "-" + months + "-" + days + "T" + hours + ":" + minutes + ":" + seconds + ".999";
}

function checkstatus()
{
	$.ajax(
		{
			dataType: "json",
			url: pathcgi + "cgi-bin/vparcgi.cgi?computerid=" + computerid + "&oper=getident&d=" + getStringNormalDate(new Date()) + localStorage.getItem("TOKEN"),
			async: false,
			success: function(data)
			{
				CheckTokenValidity(data);
				ident = data;
				$.ajax(
					{
						url: pathcgi + "/cgi-bin/vparcgi.cgi?computerid=1&oper=status&d=" + getStringNormalDate(new Date()) + localStorage.getItem("TOKEN"),
						async: false,
						success: function(data)
						{
							CheckTokenValidity(data);
							if (data[11].value == -1)
							{
								$.ajax(
								{
									url: pathcgi + "/cgi-bin/vparcgi.cgi?computerid=1&oper=checkservice&d=" + getStringNormalDate(new Date()) + localStorage.getItem("TOKEN"),
									async: false
								});
							}
						},
						error: function()
						{
							$.ajax(
								{
									url: pathcgi + "/cgi-bin/vparcgi.cgi?computerid=1&oper=checkservice&d=" + getStringNormalDate(new Date()) + localStorage.getItem("TOKEN"),
									async: false,
									success: function(data)
									{
										CheckTokenValidity(data);
									});
							}
						});
				}
			});
	}

	function startapp()
	{
		$.ajax(
		{
			url: pathcgi + "../cgi-bin/admin/vadpctrl.cgi?cmd=start&idx=" + ident + "&d=" + getStringNormalDate(new Date()) + localStorage.getItem("TOKEN"),
			success: function(data)
			{
				CheckTokenValidity(data);
				if (lp === undefined)
				{
					// se ejecutan estas instrucciones
				}
				else
				{
					lp.hide();
					DevExpress.ui.notify("Application restarted", "success", 600);
				}
			}
		});
	}

	function restartapp()
	{
		if (vivotekrestart)
		{
			$.ajax(
			{
				url: pathcgi + "../cgi-bin/admin/vadpctrl.cgi?cmd=stop&idx=" + ident + "&d=" + getStringNormalDate(new Date()) + localStorage.getItem("TOKEN"),
				success: function(data)
				{
					CheckTokenValidity(data);
				}
			});
			setTimeout(startapp, 1000);
		}
		else
		{
			$.ajax(
			{
				url: pathcgi + "cgi-bin/vparcgi.cgi?computerid=1&oper=restartservice&d=" + getStringNormalDate(new Date()) + localStorage.getItem("TOKEN"),
				success: function(data)
				{
					CheckTokenValidity(data);
				}
			});
			lp.hide();
			DevExpress.ui.notify("Application restarted", "success", 600);
		}
	}

	function CreateToolTip(id, evidences, imagepath, resultleft, resulttop, resultright, resultbottom, width, height)
	{
		$("#tooltip" + id).dxTooltip(
		{
			target: "#icimg" + id,
			showEvent: "mouseenter",
			hideEvent: "mouseleave",
			position: "left",
			contentTemplate: function(data)
			{
				var widthdraw = 700;
				var heightdraw = 394;
				var hdr = 0;
				var wdr = 700;
				if (evidences == 0)
				{
					hdr = 395;
					wdr = 700;
				}
				if (evidences == 1)
				{
					hdr = (heightdraw * 0.75) * 2;
					wdr = wdr * 0.75;
					widthdraw = widthdraw * 0.75;
					heightdraw = heightdraw * 0.75;
				}
				if (evidences == 2)
				{
					hdr = (heightdraw * 0.6) * 3;
					wdr = wdr * 0.6;
					widthdraw = widthdraw * 0.60;
					heightdraw = heightdraw * 0.60;
				}
				data.html("<canvas id='cvas" + id + "' width='" + wdr + "' height='" + hdr + "' ></canvas>");
				var canvas = document.getElementById('cvas' + id);
				var ctx = canvas.getContext('2d');
				var tmpImg = new Image();
				tmpImg.src = getImageFromCamera(pathcgi, computerid, imagepath);
				tmpImg.onload = function()
				{
					ctx.drawImage(tmpImg, 0, 0, widthdraw, heightdraw);
					ctx.rect(resultleft * (widthdraw / width), resulttop * (heightdraw / height), (resultright - resultleft) * (widthdraw / width), (resultbottom - resulttop) * (heightdraw / height));
					ctx.strokeStyle = 'green';
					ctx.lineWidth = 3;
					ctx.stroke();
				}
				if (evidences > 0)
				{
					var tmpImg2 = new Image();
					tmpImg2.src = getImageFromCamera(pathcgi, computerid, imagepath.substring(0, imagepath.length - 4) + "_ev1.jpg");
					tmpImg2.onload = function()
					{
						ctx.drawImage(tmpImg2, 0, heightdraw + 3, widthdraw, heightdraw);
						ctx.stroke();
					}
				}
				if (evidences > 1)
				{
					var tmpImg3 = new Image();
					tmpImg3.src = getImageFromCamera(pathcgi, computerid, imagepath.substring(0, imagepath.length - 4) + "_ev2.jpg");
					tmpImg3.onload = function()
					{
						ctx.drawImage(tmpImg3, 0, (heightdraw * 2) + 6, widthdraw, heightdraw);
						ctx.stroke();
					}
				}
			}
		});
	}

	function CreateToolTipTop(id, evidences, imagepath, resultleft, resulttop, resultright, resultbottom, width, height)
	{
		$("#tooltip" + id).dxTooltip(
		{
			target: "#icimg" + id,
			showEvent: "mouseenter",
			hideEvent: "mouseleave",
			position: "top",
			contentTemplate: function(data)
			{
				var widthdraw = 700;
				var heightdraw = 394;
				var hdr = 395;
				var wdr = 700;
				if (evidences == 0)
				{
					hdr = 395;
					wdr = 700;
				}
				if (evidences == 1)
				{
					hdr = heightdraw * 0.75;
					wdr = (wdr * 0.75) * 2;
					widthdraw = widthdraw * 0.75;
					heightdraw = heightdraw * 0.75;
				}
				if (evidences == 2)
				{
					hdr = heightdraw * 0.6;
					wdr = (wdr * 0.6) * 3;
					widthdraw = widthdraw * 0.60;
					heightdraw = heightdraw * 0.60;
				}
				data.html("<canvas id='cvas" + id + "' width='" + wdr + "' height='" + hdr + "' ></canvas>");
				var canvas = document.getElementById('cvas' + id);
				var ctx = canvas.getContext('2d');
				var tmpImg = new Image();
				tmpImg.src = getImageFromCamera(pathcgi, computerid, imagepath);
				tmpImg.onload = function()
				{
					ctx.drawImage(tmpImg, 0, 0, widthdraw, heightdraw);
					ctx.rect(resultleft * (widthdraw / width), resulttop * (heightdraw / height), (resultright - resultleft) * (widthdraw / width), (resultbottom - resulttop) * (heightdraw / height));
					ctx.strokeStyle = 'green';
					ctx.lineWidth = 3;
					ctx.stroke();
				}
				if (evidences > 0)
				{
					var tmpImg2 = new Image();
					tmpImg2.src = getImageFromCamera(pathcgi, computerid, imagepath.substring(0, imagepath.length - 4) + "_ev1.jpg");
					tmpImg2.onload = function()
					{
						ctx.drawImage(tmpImg2, widthdraw + 3, 0, widthdraw, heightdraw);
						ctx.stroke();
					}
				}
				if (evidences > 1)
				{
					var tmpImg3 = new Image();
					tmpImg3.src = getImageFromCamera(pathcgi, computerid, imagepath.substring(0, imagepath.length - 4) + "_ev2.jpg");
					tmpImg3.onload = function()
					{
						ctx.drawImage(tmpImg3, (widthdraw * 2) + 6, 0, widthdraw, heightdraw);
						ctx.stroke();
					}
				}
			}
		});
	}
